@@ -1,12 +1,9 @@
 import copy
-import six
 
-from samtranslator.model.naming import GeneratedLogicalId
 from samtranslator.model.intrinsics import make_combined_condition
 from samtranslator.public.plugins import BasePlugin
-from samtranslator.public.swagger import SwaggerEditor
 from samtranslator.public.exceptions import InvalidDocumentException, InvalidResourceException, InvalidEventException
-from samtranslator.public.sdk.resource import SamResourceType, SamResource
+from samtranslator.public.sdk.resource import SamResourceType
 from samtranslator.public.sdk.template import SamTemplate
 
 
@@ -32,18 +29,21 @@ class ImplicitApiPlugin(BasePlugin):
 
     """
 
-    def __init__(self):
+    def __init__(self, name):
         """
         Initialize the plugin
         """
-        super(ImplicitApiPlugin, self).__init__(ImplicitApiPlugin.__name__)
+        super(ImplicitApiPlugin, self).__init__(name)
 
-        self.implicit_api_logical_id = GeneratedLogicalId.implicit_api()
         self.existing_implicit_api_resource = None
         # dict containing condition (or None) for each resource path+method for all APIs. dict format:
         # {api_id: {path: {method: condition_name_or_None}}}
         self.api_conditions = {}
-        self.implicit_api_condition = 'ServerlessRestApiCondition'
+        self._setup_api_properties()
+
+    def _setup_api_properties(self):
+        raise NotImplementedError("Method _setup_api_properties() must be implemented in a "
+                                  "subclass of ImplicitApiPlugin")
 
     def on_before_transform_template(self, template_dict):
         """
@@ -65,7 +65,7 @@ class ImplicitApiPlugin(BasePlugin):
         # removing the "ServerlessRestApi" resource, we just restore what the author defined.
         self.existing_implicit_api_resource = copy.deepcopy(template.get(self.implicit_api_logical_id))
 
-        template.set(self.implicit_api_logical_id, ImplicitApiResource().to_dict())
+        template.set(self.implicit_api_logical_id, self._generate_implicit_api_resource())
 
         errors = []
         for logicalId, function in template.iterate(SamResourceType.Function.value):
@@ -112,7 +112,7 @@ class ImplicitApiPlugin(BasePlugin):
         api_events = {}
         for event_id, event in function.properties["Events"].items():
 
-            if event and isinstance(event, dict) and event.get("Type") == "Api":
+            if event and isinstance(event, dict) and event.get("Type") == self.api_event_type:
                 api_events[event_id] = event
 
         return api_events
@@ -127,39 +127,8 @@ class ImplicitApiPlugin(BasePlugin):
         :param SamTemplate template: SAM Template where Serverless::Api resources can be found
         :param str condition: optional; this is the condition that is on the function with the API event
         """
-
-        for logicalId, event in api_events.items():
-
-            event_properties = event.get("Properties", {})
-            if not event_properties:
-                continue
-
-            self._add_implicit_api_id_if_necessary(event_properties)
-
-            api_id = self._get_api_id(event_properties)
-            try:
-                path = event_properties["Path"]
-                method = event_properties["Method"]
-            except KeyError as e:
-                raise InvalidEventException(logicalId, "Event is missing key {}.".format(e))
-
-            if (not isinstance(path, six.string_types)):
-                raise InvalidEventException(logicalId,
-                                            "Api Event must have a String specified for 'Path'.")
-            if (not isinstance(method, six.string_types)):
-                raise InvalidEventException(logicalId,
-                                            "Api Event must have a String specified for 'Method'.")
-
-            api_dict = self.api_conditions.setdefault(api_id, {})
-            method_conditions = api_dict.setdefault(path, {})
-            method_conditions[method] = condition
-
-            self._add_api_to_swagger(logicalId, event_properties, template)
-
-            api_events[logicalId] = event
-
-        # We could have made changes to the Events structure. Write it back to function
-        function.properties["Events"].update(api_events)
+        raise NotImplementedError("Method _setup_api_properties() must be implemented in a "
+                                  "subclass of ImplicitApiPlugin")
 
     def _add_implicit_api_id_if_necessary(self, event_properties):
         """
@@ -169,8 +138,8 @@ class ImplicitApiPlugin(BasePlugin):
 
         :param dict event_properties: Dictionary of event properties
         """
-        if "RestApiId" not in event_properties:
-            event_properties["RestApiId"] = {"Ref": self.implicit_api_logical_id}
+        raise NotImplementedError("Method _setup_api_properties() must be implemented in a "
+                                  "subclass of ImplicitApiPlugin")
 
     def _add_api_to_swagger(self, event_id, event_properties, template):
         """
@@ -195,7 +164,7 @@ class ImplicitApiPlugin(BasePlugin):
         resource = template.get(api_id)
         if not (resource and
                 isinstance(resource.properties, dict) and
-                SwaggerEditor.is_valid(resource.properties.get("DefinitionBody"))):
+                self.editor.is_valid(resource.properties.get("DefinitionBody"))):
             # This does not have an inline Swagger. Nothing can be done about it.
             return
 
@@ -214,10 +183,10 @@ class ImplicitApiPlugin(BasePlugin):
 
         path = event_properties["Path"]
         method = event_properties["Method"]
-        editor = SwaggerEditor(swagger)
+        editor = self.editor(swagger)
         editor.add_path(path, method)
 
-        resource.properties["DefinitionBody"] = editor.swagger
+        resource.properties["DefinitionBody"] = self._get_api_definition_from_editor(editor)
         template.set(api_id, resource)
 
     def _get_api_id(self, event_properties):
@@ -226,7 +195,7 @@ class ImplicitApiPlugin(BasePlugin):
 
         Handles case where API id is not specified or is a reference to a logical id.
         """
-        api_id = event_properties.get("RestApiId")
+        api_id = event_properties.get(self.api_id_property)
         if isinstance(api_id, dict) and "Ref" in api_id:
             api_id = api_id["Ref"]
         return api_id
@@ -291,12 +260,12 @@ class ImplicitApiPlugin(BasePlugin):
         that composite condition is added to the resource path.
         """
 
-        for api_id, api in template.iterate(SamResourceType.Api.value):
+        for api_id, api in template.iterate(self.api_type):
             if not api.properties.get('__MANAGE_SWAGGER'):
                 continue
 
             swagger = api.properties.get("DefinitionBody")
-            editor = SwaggerEditor(swagger)
+            editor = self.editor(swagger)
 
             for path in editor.iter_on_path():
                 all_method_conditions = set(
@@ -313,9 +282,16 @@ class ImplicitApiPlugin(BasePlugin):
                             template.template_dict, path_condition_name, all_method_conditions)
                         editor.make_path_conditional(path, path_condition_name)
 
-            api.properties["DefinitionBody"] = editor.swagger
+            api.properties["DefinitionBody"] = self._get_api_definition_from_editor(editor)  # TODO make static method
             template.set(api_id, api)
 
+    def _get_api_definition_from_editor(self, editor):
+        """
+        Required function that returns the api body from the respective editor
+        """
+        raise NotImplementedError("Method _setup_api_properties() must be implemented in a "
+                                  "subclass of ImplicitApiPlugin")
+
     def _path_condition_name(self, api_id, path):
         """
         Generate valid condition logical id from the given API logical id and swagger resource path.
@@ -346,30 +322,9 @@ class ImplicitApiPlugin(BasePlugin):
             else:
                 template.delete(self.implicit_api_logical_id)
 
-
-class ImplicitApiResource(SamResource):
-    """
-    Returns a AWS::Serverless::Api resource representing the Implicit APIs. The returned resource includes
-    the empty swagger along with default values for other properties.
-    """
-
-    def __init__(self):
-        swagger = SwaggerEditor.gen_skeleton()
-
-        resource = {
-            "Type": SamResourceType.Api.value,
-            "Properties": {
-
-                # Because we set the StageName to be constant value here, customers cannot override StageName with
-                # Globals. This is because, if a property is specified in both Globals and the resource, the resource
-                # one takes precedence.
-                "StageName": "Prod",
-
-                "DefinitionBody": swagger,
-                # Internal property that means Event source code can add Events. Used only for implicit APIs, to
-                # prevent back compatibility issues for explicit APIs
-                "__MANAGE_SWAGGER": True
-            }
-        }
-
-        super(ImplicitApiResource, self).__init__(resource)
+    def _generate_implicit_api_resource(self):
+        """
+        Helper function implemented by child classes that create a new implicit API resource
+        """
+        raise NotImplementedError("Method _setup_api_properties() must be implemented in a "
+                                  "subclass of ImplicitApiPlugin")
