@@ -36,7 +36,8 @@ class Globals(object):
             "Layers",
             "DeploymentPreference",
             "PermissionsBoundary",
-            "ReservedConcurrentExecutions"
+            "ReservedConcurrentExecutions",
+            "ProvisionedConcurrencyConfig"
         ],
 
         # Everything except
@@ -62,6 +63,13 @@ class Globals(object):
             "OpenApiVersion"
         ],
 
+        SamResourceType.HttpApi.value: [
+            "Auth",
+            "AccessLogSettings",
+            "StageVariables",
+            "Tags"
+        ],
+
         SamResourceType.SimpleTable.value: [
             "SSESpecification"
         ]
@@ -156,7 +164,6 @@ class Globals(object):
         """
 
         globals = {}
-
         if not isinstance(globals_dict, dict):
             raise InvalidGlobalsSectionException(self._KEYWORD,
                                                  "It must be a non-empty dictionary".format(self._KEYWORD))
