@@ -1421,7 +1421,6 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
 
         self.assertEqual(deep_sort_lists(expected), deep_sort_lists(self.editor.swagger[_X_POLICY]))
 
-    @patch("boto3.session.Session.region_name", "eu-west-2")
     def test_must_add_iam_allow(self):
 ## fails
         resourcePolicy = {
@@ -1438,14 +1437,14 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
                 'Action': 'execute-api:Invoke',
                 'Resource': [{
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/PUT/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/PUT/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     },
                     {
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/GET/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/GET/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     }],
                 'Effect': 'Allow',
@@ -1457,7 +1456,6 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
 
         self.assertEqual(deep_sort_lists(expected), deep_sort_lists(self.editor.swagger[_X_POLICY]))
 
-    @patch("boto3.session.Session.region_name", "eu-west-2")
     def test_must_add_iam_deny(self):
 
         resourcePolicy = {
@@ -1474,14 +1472,14 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
                 'Action': 'execute-api:Invoke',
                 'Resource': [{
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/PUT/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/PUT/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     },
                     {
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/GET/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/GET/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     }],
                 'Effect': 'Deny',
@@ -1493,7 +1491,6 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
 
         self.assertEqual(deep_sort_lists(expected), deep_sort_lists(self.editor.swagger[_X_POLICY]))
 
-    @patch("boto3.session.Session.region_name", "eu-west-2")
     def test_must_add_ip_allow(self):
 
         resourcePolicy = {
@@ -1510,14 +1507,14 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
                 'Action': 'execute-api:Invoke',
                 'Resource': [{
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/PUT/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/PUT/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     },
                     {
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/GET/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/GET/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     }],
                 'Effect': 'Allow',
@@ -1527,14 +1524,14 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
                 'Action': 'execute-api:Invoke',
                 'Resource': [{
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/PUT/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/PUT/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     },
                     {
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/GET/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/GET/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     }],
                 'Effect': 'Deny',
@@ -1549,7 +1546,6 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
 
         self.assertEqual(deep_sort_lists(expected), deep_sort_lists(self.editor.swagger[_X_POLICY]))
 
-    @patch("boto3.session.Session.region_name", "eu-west-2")
     def test_must_add_ip_deny(self):
 
         resourcePolicy = {
@@ -1566,14 +1562,14 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
                 'Action': 'execute-api:Invoke',
                 'Resource': [{
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/PUT/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/PUT/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     },
                     {
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/GET/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/GET/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     }],
                 'Effect': 'Allow',
@@ -1583,14 +1579,14 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
                 'Action': 'execute-api:Invoke',
                 'Resource': [{
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/PUT/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/PUT/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     },
                     {
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/GET/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/GET/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     }],
                 'Effect': 'Deny',
@@ -1605,7 +1601,6 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
 
         self.assertEqual(deep_sort_lists(expected), deep_sort_lists(self.editor.swagger[_X_POLICY]))
 
-    @patch("boto3.session.Session.region_name", "eu-west-2")
     def test_must_add_vpc_allow(self):
 
         resourcePolicy = {
@@ -1624,14 +1619,14 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
                     'Action': 'execute-api:Invoke',
                     'Resource': [{
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/PUT/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/PUT/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     },
                     {
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/GET/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/GET/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     }],
                     'Effect': 'Allow',
@@ -1641,14 +1636,14 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
                     'Action': 'execute-api:Invoke',
                     'Resource': [{
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/PUT/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/PUT/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     },
                     {
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/GET/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/GET/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     }],
                     'Effect': 'Deny',
@@ -1663,14 +1658,14 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
                     'Action': 'execute-api:Invoke',
                     'Resource': [{
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/PUT/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/PUT/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     },
                     {
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/GET/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/GET/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     }],
                     'Effect': 'Deny',
@@ -1686,7 +1681,6 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
 
         self.assertEqual(deep_sort_lists(expected), deep_sort_lists(self.editor.swagger[_X_POLICY]))
 
-    @patch("boto3.session.Session.region_name", "eu-west-2")
     def test_must_add_vpc_deny(self):
 
         resourcePolicy = {
@@ -1704,14 +1698,14 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
                     'Action': 'execute-api:Invoke',
                     'Resource': [{
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/PUT/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/PUT/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     },
                     {
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/GET/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/GET/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     }],
                     'Effect': 'Allow',
@@ -1721,14 +1715,14 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
                     'Action': 'execute-api:Invoke',
                     'Resource': [                {
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/PUT/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/PUT/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     },
                     {
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/GET/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/GET/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     }],
                     'Effect': 'Deny',
@@ -1744,9 +1738,7 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
 
         self.assertEqual(deep_sort_lists(expected), deep_sort_lists(self.editor.swagger[_X_POLICY]))
 
-    @patch("boto3.session.Session.region_name", "eu-west-2")
     def test_must_add_iam_allow_and_custom(self):
-## fails
         resourcePolicy = {
             'AwsAccountWhitelist': [
                 '123456'
@@ -1769,14 +1761,14 @@ class TestSwaggerEditor_add_resource_policy(TestCase):
                 'Action': 'execute-api:Invoke',
                 'Resource': [{
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/PUT/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/PUT/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     },
                     {
                         'Fn::Sub': [
-                            'arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${__ApiId__}/${__Stage__}/GET/foo',
-                            {'__Stage__': 'prod', '__ApiId__': '123'}
+                            'execute-api:/${__Stage__}/GET/foo',
+                            {'__Stage__': 'prod'}
                         ]
                     }],
                 'Effect': 'Allow',
